package logs

import (
	"testing"
	"time"
)

func TestNewStdout(t *testing.T) {
	std := NewStdout()
	for {
		time.Sleep(100 * time.Millisecond)
		std.Println("TestNewStdout: %s", time.Now())

		std.Action("TestNewStdout: %s", time.Now())
		std.Device("TestNewStdout: %s", time.Now())
		std.Safety("TestNewStdout: %s", time.Now())
	}

}

func TestNew2(t *testing.T) {
	logs := New("svc", "/dev/stdout")
	logs.Println("TestNewStdout: %s", time.Now())

	logs.Action("TestNewStdout: %s", time.Now())
	logs.Device("TestNewStdout: %s", time.Now())
	logs.Safety("TestNewStdout: %s", time.Now())
}
